#

##

    	itinerary

    		[ ] mongo instead of tinydb

    			[ ] save & rebuild, export & dump

    			[ ] two URLs
    				( ) mongo cloud URL
    				( ) local URL

    		[ ] essence
    			( ) from path
    			( ) configurable in memory

    			[ ] search "essence.py" in CWD by preset

    		[ ] food treasure:nature from mongo ingredients

    		[ ] supp treasure:nature from mongo ingredients

    		itinerary, ranked:
    			[ ] fractional amounts of essentials

    			[ ] supp, fractional amounts of measured ingredients

    			maybe:
    				[ ] food, fractional amounts of measured ingredients

    			[ ] clouds/food_USDA/nature_v2/_status/status_2_form.py

    					change serving size unit to "grams" from "g"?

    		possibilities

    			[ ] 100% organic eco-friendly from sustainable farming.

    			instances:
    				programmatic:
    					import apoplast
    					apoplast_1 = apoplast.instantiate ()

    				click:
    					[xonsh] apoplast instantiate